/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2010 Bull S.A.S.
 * Copyright (C) 2010 EMN
 * Copyright (C) 2010 IRISA
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Author(s):
 * 		Mahmoud Ben Hassine (IRISA)
 *  
 */
package org.ow2.wildcat.examples.bank;

import org.ow2.wildcat.examples.bank.util.InsufficientAmountException;
import org.ow2.wildcat.examples.bank.util.TxDetails;

/**
 * Class representing a bank account
 * @author Mahmoud Ben Hassine
 *
 */
public class Account {

	private int id;
	private double balance;
	private Customer owner; // customer-account is a one-to-one relation
	private AccountSensor accountSensor; // wildcat sensor

    public Account(int id) {
		this.id = id;
		balance = 0;
		accountSensor = new AccountSensor();
	}
    
    public Account(int id, double initialBalance) {
        this.id = id;
        this.balance = initialBalance;
        accountSensor = new AccountSensor();
    }

    public int getId() {
        return id;
    }

    public Customer getOwner() {
        return owner;
    }

    public void setOwner(Customer owner) {
        this.owner = owner;
    }

    public double getBalance() {
        return balance;
    }
 
    public AccountSensor getSensor() {
        return accountSensor;
    }

	public void deposit(double amount) throws IllegalArgumentException{
		if (amount < 0)
			throw new IllegalArgumentException(
					" negative amount for a deposit operation");
		double oldBalance = balance;
		balance += amount;
		//notify changes to the wildcat context that this sensor is mount/connected to
		accountSensor.setValue(new TxDetails(this, oldBalance, balance,
			java.util.Calendar.getInstance().getTime()));
	}

	public void withdraw(double amount) throws InsufficientAmountException,
			IllegalArgumentException {
		if (amount < 0)
			throw new IllegalArgumentException(
					" negative amount for a withdraw operation");

		if (balance - amount < 0)
			throw new InsufficientAmountException(
					" insufficient balance for a withdraw operation");
		
		double oldBalance = balance;
		this.balance -= amount;
		//notify changes to the wildcat context that this sensor is mount/connected to
		accountSensor.setValue(new TxDetails(this, oldBalance, balance,
				java.util.Calendar.getInstance().getTime()));
	}
	
	public String toString(){
		return "id = " + id;
	}
}
