/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2010 Bull S.A.S.
 * Copyright (C) 2010 EMN
 * Copyright (C) 2010 IRISA
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Author(s):
 * 		Mahmoud Ben Hassine (IRISA)
 *  
 */
package org.ow2.wildcat.examples.bank.util;

import java.util.Vector;

import org.ow2.wildcat.examples.bank.Account;
import org.ow2.wildcat.examples.bank.Customer;


/**
 * Utility class representing the bank database. Implements the singleton pattern
 * @author Mahmoud Ben Hassine
 *
 */

public class BankDataBase {

	private static BankDataBase database;
	
	private Vector<Customer> customers;
	private Vector<Account> accounts;
	
	private BankDataBase(){
		
        //create some Account instances
        Account a1 = new Account(1, 15000);
        Account a2 = new Account(2, 13000);
        Account a3 = new Account(3, 70000);
        Account a4 = new Account(4, 20000);
        Account a5 = new Account(5, 6500);
        Account a6 = new Account(6, 30000);

        //create some Customer instances
        Customer c1 = new Customer(1,"Adam","Brown",a1);
        Customer c2 = new Customer(2,"James","Jakson",a2);
        Customer c3 = new Customer(3,"Victoria","Brain",a3);
        Customer c4 = new Customer(4,"Freddy","Tayson",a4);
        Customer c5 = new Customer(5,"Yasmine","James",a5);
        Customer c6 = new Customer(6,"Susan","Olivera",a6);

        //associate accounts to customers
        a1.setOwner(c1);a2.setOwner(c2);
        a3.setOwner(c3);a4.setOwner(c4);
        a5.setOwner(c5);a6.setOwner(c6);
  	
        //add accounts to the Account Vector
        accounts = new Vector<Account>();
        accounts.add(a1);accounts.add(a2);
        accounts.add(a3);accounts.add(a4);
        accounts.add(a5);accounts.add(a6);
        
        //add customers to the Customer Vector
        customers = new Vector<Customer>();
        customers.add(c1);customers.add(c2);
        customers.add(c3);customers.add(c4);
        customers.add(c5);customers.add(c6);
	}
	
	public static BankDataBase getInstance(){
		if (database == null){
			database = new BankDataBase();
		}
		return database;
	}
	
	public Vector<Customer> getCustomers(){		
		return customers;
	}
	
	public Vector<Account> getAccounts(){		
		return accounts;
	}

}
