/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2010 Bull S.A.S.
 * Copyright (C) 2010 EMN
 * Copyright (C) 2010 IRISA
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Author(s):
 * 		Mahmoud Ben Hassine (IRISA)
 *  
 */
package org.ow2.wildcat.sca.intent;


import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.api.Interface;
import org.objectweb.fractal.util.Fractal;

import org.osoa.sca.annotations.Init;
import org.ow2.frascati.tinfi.control.intent.IntentHandler;
import org.ow2.frascati.tinfi.control.intent.IntentJoinPoint;

import org.ow2.wildcat.sca.intent.WildcatContext;


/**
 * Intent used to notify monitoring data of service events to wildcat context
 * 
 * @version 1.0 
 * @author Mahmoud Ben Hassine
 *
 */
public class MonitoringIntentHandler implements IntentHandler {
	
	private long startTime;
	private long estimatedTime;
	
	/**
	 * Monitoring data to be sent to wildcat context
	 */
	MonitoringData monitoringData;

	@Init
	public void init() {
	  monitoringData = new MonitoringData();
	}
	
	public Object invoke(IntentJoinPoint ijp) throws Throwable {

	    Component c = ((Interface) ijp.getComponentContext()).getFcItfOwner();
	    String componentName = Fractal.getNameController(c).getFcName();
	    String serviceName = ijp.getInterface().getFcItfName();
	    String methodName = ijp.getMethod().getName();
		
		Object ret = null;
		
		startTime = System.currentTimeMillis();
		    
		 ret = ijp.proceed();
		    
		estimatedTime = System.currentTimeMillis() - startTime;
		
		/*
		 * Set monitoring data to be notified
		 */
		monitoringData.setComponentName(componentName);
		monitoringData.setServiceName(serviceName);
		monitoringData.setMethodName(methodName);
		monitoringData.setResponseTime(estimatedTime);
		
		/*
		 * notify monitoring data to wildcat context
		 */
		WildcatContext.getInstance().notify(monitoringData);
		
		return ret;
	}

}
