/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2008-2009 Bull S.A.S.
 * Copyright (C) 2008 EMN
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * --------------------------------------------------------------------------
 * $Id: TopicToSpy.java 420 2009-06-07 09:15:52Z loris $
 * --------------------------------------------------------------------------
 */
package org.ow2.wildcat.remote.dispatcher;

import java.util.HashSet;
import java.util.Set;

import javax.jms.MessageConsumer;
import javax.jms.Session;
import javax.jms.Topic;

import org.ow2.wildcat.Context;

/**
 * Regroup the {@link Context} listening for events coming from an other {@link Context}.
 * @author Loris Bouzonnet
 */
public final class TopicToSpy {

    /**
     * Local contexts listening for events coming from this topic.
     */
    private final Set<Context> spyingContexts;

    private final MessageConsumer consumer;

    private final Session sessionToSpy;

    private final Topic topicToSpy;


    public TopicToSpy(final Topic topic,
            final MessageConsumer consumer, final Session session) {
        spyingContexts = new HashSet<Context>();
        this.consumer = consumer;
        this.topicToSpy = topic;
        this.sessionToSpy = session;
    }


    protected final Set<Context> getSpyingContexts() {
        return spyingContexts;
    }


    protected final MessageConsumer getConsumer() {
        return consumer;
    }


    protected final Session getSessionToSpy() {
        return sessionToSpy;
    }

    protected final Topic getTopicToSpy() {
        return topicToSpy;
    }

}
