/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 EMN
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * Authors:
 *		- Pierre-Charles David (initial)
 *		- Nicolas Loriant
 * --------------------------------------------------------------------------
 * $Id: SensorLibrary.java 398 2009-01-02 10:53:18Z loris $
 * --------------------------------------------------------------------------
 */
package org.ow2.wildcat.sensors;

import java.util.HashMap;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * A Factory/Manager for Sensors.
 */
public class SensorLibrary {

    private static Log logger = LogFactory.getLog(SensorLibrary.class);

    /**
     * Default SensorLibrary. Reference every sensors
     */
    public static final SensorLibrary DEFAULT = new SensorLibrary();

    static {
        try {
            DEFAULT.library.put("CPUInfo", CPUInfoSensor.class);
            DEFAULT.library.put("CPULoad", CPULoadSensor.class);
            DEFAULT.library.put("DateTime", DateTimeSensor.class);
            DEFAULT.library.put("JavaRuntime", JavaRuntimeSensor.class);
            DEFAULT.library.put("KernelVersion", KernelVersionSensor.class);
            DEFAULT.library.put("Null", NullSensor.class);
            DEFAULT.library.put("SystemProperties",
                    SystemPropertiesSensor.class);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private Map<String, Class<? extends Sensor>> library;

    public SensorLibrary() {
        this.library = new HashMap<String, Class<? extends Sensor>>();
    }

    public boolean contains(final String sensor) {
        return this.library.containsKey(sensor);
    }

    /**
     * Instantiate a Sensor
     *
     * @param sensor
     *            sensor's name
     * @return a new Sensor of type "sensor", or a new NullSensor if sensor
     *         can't be resolved
     */
    public Sensor instanciate(final String sensor) {
        try {
            return this.library.get(sensor).newInstance();
        } catch (Exception e) {
            logger.info("Failled instanciating sensor '" + sensor + "'", e);
            return new NullSensor();
        }
    }
}
