/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2008-2009 Bull S.A.S.
 * Copyright (C) 2008 EMN
 * Copyright (C) 2008 IRISA
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * --------------------------------------------------------------------------
 * $Id: TestHierarchyBasicOperations.java 539 2010-07-13 09:42:46Z mahmoudbh $
 * --------------------------------------------------------------------------
 */
package org.ow2.wildcat.test;

import org.ow2.wildcat.Context;
import org.ow2.wildcat.ContextException;
import org.ow2.wildcat.ContextFactory;
import org.ow2.wildcat.hierarchy.Path;
import org.ow2.wildcat.hierarchy.resource.Resource;
import org.ow2.wildcat.sensors.SensorLibrary;
import org.testng.Assert;
import org.testng.annotations.AfterClass;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

public class TestHierarchyBasicOperations {

	private Context ctx;
	
	@BeforeMethod
	protected void setUp() throws Exception {
		ctx = ContextFactory.getDefaultFactory().createContext();
	}

	@Test
	public void testdetachResource() throws ContextException {
		
        ctx.createResource("self://resource1/resource3");
        ctx.createResource("self://resource2");

        ctx.detachResource("self://resource1");

        Assert.assertEquals("[resource2]", ctx.list("self://").toString());

    }

	@Test
    public void testdetachLinkedResource() throws ContextException {

        ctx.createResource("self://resource1");
        ctx.createResource("self://resource2");

        ctx.createAttribute("self://resource1#att", "a1");

        ctx.createSymlink("self://link", "self://resource1");

        ctx.detachResource("self://resource1");
        Assert.assertEquals(null, ctx.list("self://link"));

    }

	@Test
    public void testdestroyContext() throws ContextException {

        ctx.createAttribute("self://start#a1", "start");
        ctx.createAttribute("self://start#a2", "end");
        ctx.createResource("self://resource");
        ctx.destroy();
        Assert.assertEquals("[]", ctx.list("self://").toString());

    }

	@Test
    public void testGetResource() throws ContextException {

        ctx.createResource("self://r1/r3");
        ctx.createResource("self://r2");

        Resource r = ctx.getResource("self://r1/r3");

        Assert.assertNotNull(r);

    }

	@Test
    public void testPath() throws Exception {
        Path path1 = new Path("self://foo/bar");
        Path path2 = new Path("self://foo/bar#att");
        Assert.assertEquals(path1.getParentPath().appendResource("bar"), path2.getParentPath());
    }

	@Test
    public void testdetachAttribute() throws ContextException {

        ctx.attachAttribute("self://start#time", SensorLibrary.DEFAULT
                .instanciate("DateTime"));

        ctx.detachAttribute("self://start#time");
        Assert.assertNull(ctx.getValue("self://start#time"));
    }
    
    @AfterClass
	protected void tearDown() throws Exception {
		ctx = null;
		System.gc();
	}

}
